@@ -1496,79 +1496,79 @@ n <- 20
 m <- rnorm(1)
 
 ## Generate variates
-(Rfpareto <- rfpareto(n, min = m, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2))
-(Rpareto4 <- rpareto4(n, min = m, shape1 = 0.8, shape2 = 1.5,             scale = 2))
-(Rpareto3 <- rpareto3(n, min = m,               shape  = 1.5,             scale = 2))
-(Rpareto2 <- rpareto2(n, min = m, shape  = 0.8,                           scale = 2))
-(Rtrbeta        <- rtrbeta      (n, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2))
-(Rburr          <- rburr        (n, shape1 = 0.8, shape2 = 1.5,             scale = 2))
-(Rllogis        <- rllogis      (n, shape  = 1.5, scale = 2))
-(Rparalogis     <- rparalogis   (n, shape  = 0.8, scale = 2))
-(Rgenpareto     <- rgenpareto   (n, shape1 = 0.8, shape2 = 2, scale = 2))
-(Rpareto        <- rpareto      (n, shape  = 0.8, scale = 2))
-(Rpareto1       <- rpareto1     (n, shape  = 0.8, min = 2))
-(Rinvburr       <- rinvburr     (n, shape1 = 1.5, shape2 = 2, scale = 2))
-(Rinvpareto     <- rinvpareto   (n, shape  = 2,   scale = 2))
-(Rinvparalogis  <- rinvparalogis(n, shape  = 2,   scale = 2))
-(Rtrgamma       <- rtrgamma     (n, shape1 = 2, shape2 = 3, scale = 5))
-(Rinvtrgamma    <- rinvtrgamma  (n, shape1 = 2, shape2 = 3, scale = 5))
-(Rinvgamma      <- rinvgamma    (n, shape  = 2,             scale = 5))
-(Rinvweibull    <- rinvweibull  (n,             shape  = 3, scale = 5))
-(Rinvexp        <- rinvexp      (n,                         scale = 5))
-(Rlgamma <- rlgamma(n, shapelog = 1.5, ratelog = 5))
-(Rgumbel <- rgumbel(n, alpha = 2, scale = 5))
-(Rinvgauss <- rinvgauss(n, mean = 2, dispersion = 5))
-(Rgenbeta <- rgenbeta(n, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2))
+Rfpareto <- rfpareto(n, min = m, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
+Rpareto4 <- rpareto4(n, min = m, shape1 = 0.8, shape2 = 1.5,             scale = 2)
+Rpareto3 <- rpareto3(n, min = m,               shape  = 1.5,             scale = 2)
+Rpareto2 <- rpareto2(n, min = m, shape  = 0.8,                           scale = 2)
+Rtrbeta        <- rtrbeta      (n, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
+Rburr          <- rburr        (n, shape1 = 0.8, shape2 = 1.5,             scale = 2)
+Rllogis        <- rllogis      (n, shape  = 1.5, scale = 2)
+Rparalogis     <- rparalogis   (n, shape  = 0.8, scale = 2)
+Rgenpareto     <- rgenpareto   (n, shape1 = 0.8, shape2 = 2, scale = 2)
+Rpareto        <- rpareto      (n, shape  = 0.8, scale = 2)
+Rpareto1       <- rpareto1     (n, shape  = 0.8, min = 2)
+Rinvburr       <- rinvburr     (n, shape1 = 1.5, shape2 = 2, scale = 2)
+Rinvpareto     <- rinvpareto   (n, shape  = 2,   scale = 2)
+Rinvparalogis  <- rinvparalogis(n, shape  = 2,   scale = 2)
+Rtrgamma       <- rtrgamma     (n, shape1 = 2, shape2 = 3, scale = 5)
+Rinvtrgamma    <- rinvtrgamma  (n, shape1 = 2, shape2 = 3, scale = 5)
+Rinvgamma      <- rinvgamma    (n, shape  = 2,             scale = 5)
+Rinvweibull    <- rinvweibull  (n,             shape  = 3, scale = 5)
+Rinvexp        <- rinvexp      (n,                         scale = 5)
+Rlgamma <- rlgamma(n, shapelog = 1.5, ratelog = 5)
+Rgumbel <- rgumbel(n, alpha = 2, scale = 5)
+Rinvgauss <- rinvgauss(n, mean = 2, dispersion = 5)
+Rgenbeta <- rgenbeta(n, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
 
 ## Compute quantiles
-(Pfpareto <- pfpareto(Rfpareto, min = m, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2))
-(Ppareto4 <- ppareto4(Rpareto4, min = m, shape1 = 0.8, shape2 = 1.5,             scale = 2))
-(Ppareto3 <- ppareto3(Rpareto3, min = m,               shape  = 1.5,             scale = 2))
-(Ppareto2 <- ppareto2(Rpareto2, min = m, shape  = 0.8,                           scale = 2))
-(Ptrbeta        <- ptrbeta      (Rtrbeta,       shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2))
-(Pburr          <- pburr        (Rburr,         shape1 = 0.8, shape2 = 1.5,             scale = 2))
-(Pllogis        <- pllogis      (Rllogis,       shape  = 1.5, scale = 2))
-(Pparalogis     <- pparalogis   (Rparalogis,    shape  = 0.8, scale = 2))
-(Pgenpareto     <- pgenpareto   (Rgenpareto,    shape1 = 0.8, shape2 = 2, scale = 2))
-(Ppareto        <- ppareto      (Rpareto,       shape  = 0.8, scale = 2))
-(Ppareto1       <- ppareto1     (Rpareto1,      shape  = 0.8, min = 2))
-(Pinvburr       <- pinvburr     (Rinvburr,      shape1 = 1.5, shape2 = 2, scale = 2))
-(Pinvpareto     <- pinvpareto   (Rinvpareto,    shape  = 2,   scale = 2))
-(Pinvparalogis  <- pinvparalogis(Rinvparalogis, shape  = 2,   scale = 2))
-(Ptrgamma       <- ptrgamma     (Rtrgamma,      shape1 = 2, shape2 = 3, scale = 5))
-(Pinvtrgamma    <- pinvtrgamma  (Rinvtrgamma,   shape1 = 2, shape2 = 3, scale = 5))
-(Pinvgamma      <- pinvgamma    (Rinvgamma,     shape  = 2,             scale = 5))
-(Pinvweibull    <- pinvweibull  (Rinvweibull,               shape  = 3, scale = 5))
-(Pinvexp        <- pinvexp      (Rinvexp,                               scale = 5))
-(Plgamma <- plgamma(Rlgamma, shapelog = 1.5, ratelog = 5))
-(Pgumbel <- pgumbel(Rgumbel, alpha = 2, scale = 5))
-(Pinvgauss <- pinvgauss(Rinvgauss, mean = 2, dispersion = 5))
-(Pgenbeta <- pgenbeta(Rgenbeta, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2))
+Pfpareto <- pfpareto(Rfpareto, min = m, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
+Ppareto4 <- ppareto4(Rpareto4, min = m, shape1 = 0.8, shape2 = 1.5,             scale = 2)
+Ppareto3 <- ppareto3(Rpareto3, min = m,               shape  = 1.5,             scale = 2)
+Ppareto2 <- ppareto2(Rpareto2, min = m, shape  = 0.8,                           scale = 2)
+Ptrbeta        <- ptrbeta      (Rtrbeta,       shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
+Pburr          <- pburr        (Rburr,         shape1 = 0.8, shape2 = 1.5,             scale = 2)
+Pllogis        <- pllogis      (Rllogis,       shape  = 1.5, scale = 2)
+Pparalogis     <- pparalogis   (Rparalogis,    shape  = 0.8, scale = 2)
+Pgenpareto     <- pgenpareto   (Rgenpareto,    shape1 = 0.8, shape2 = 2, scale = 2)
+Ppareto        <- ppareto      (Rpareto,       shape  = 0.8, scale = 2)
+Ppareto1       <- ppareto1     (Rpareto1,      shape  = 0.8, min = 2)
+Pinvburr       <- pinvburr     (Rinvburr,      shape1 = 1.5, shape2 = 2, scale = 2)
+Pinvpareto     <- pinvpareto   (Rinvpareto,    shape  = 2,   scale = 2)
+Pinvparalogis  <- pinvparalogis(Rinvparalogis, shape  = 2,   scale = 2)
+Ptrgamma       <- ptrgamma     (Rtrgamma,      shape1 = 2, shape2 = 3, scale = 5)
+Pinvtrgamma    <- pinvtrgamma  (Rinvtrgamma,   shape1 = 2, shape2 = 3, scale = 5)
+Pinvgamma      <- pinvgamma    (Rinvgamma,     shape  = 2,             scale = 5)
+Pinvweibull    <- pinvweibull  (Rinvweibull,               shape  = 3, scale = 5)
+Pinvexp        <- pinvexp      (Rinvexp,                               scale = 5)
+Plgamma <- plgamma(Rlgamma, shapelog = 1.5, ratelog = 5)
+Pgumbel <- pgumbel(Rgumbel, alpha = 2, scale = 5)
+Pinvgauss <- pinvgauss(Rinvgauss, mean = 2, dispersion = 5)
+Pgenbeta <- pgenbeta(Rgenbeta, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
 
 ## Just compute pdf
-dfpareto(Rfpareto, min = m, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
-dpareto4(Rpareto4, min = m, shape1 = 0.8, shape2 = 1.5,             scale = 2)
-dpareto3(Rpareto3, min = m,               shape  = 1.5,             scale = 2)
-dpareto2(Rpareto2, min = m, shape  = 0.8,                           scale = 2)
-dtrbeta      (Rtrbeta,       shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
-dburr        (Rburr,         shape1 = 0.8, shape2 = 1.5,             scale = 2)
-dllogis      (Rllogis,       shape  = 1.5, scale = 2)
-dparalogis   (Rparalogis,    shape  = 0.8, scale = 2)
-dgenpareto   (Rgenpareto,    shape1 = 0.8, shape2 = 2, scale = 2)
-dpareto      (Rpareto,       shape  = 0.8, scale = 2)
-dpareto1     (Rpareto1,      shape  = 0.8, min = 2)
-dinvburr     (Rinvburr,      shape1 = 1.5, shape2 = 2, scale = 2)
-dinvpareto   (Rinvpareto,    shape  = 2,   scale = 2)
-dinvparalogis(Rinvparalogis, shape  = 2,   scale = 2)
-dtrgamma     (Rtrgamma,      shape1 = 2, shape2 = 3, scale = 5)
-dinvtrgamma  (Rinvtrgamma,   shape1 = 2, shape2 = 3, scale = 5)
-dinvgamma    (Rinvtrgamma,   shape  = 2,             scale = 5)
-dinvweibull  (Rinvweibull,               shape  = 3, scale = 5)
-dinvexp      (Rinvexp,                               scale = 5)
-dlgamma(Rlgamma, shapelog = 1.5, ratelog = 5)
-dgumbel(Rgumbel, alpha = 2, scale = 5)
-dinvgauss(Rinvgauss, mean = 2, dispersion = 5)
-dgenbeta(Rgenbeta, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
+Dfpareto <- dfpareto(Rfpareto, min = m, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
+Dpareto4 <- dpareto4(Rpareto4, min = m, shape1 = 0.8, shape2 = 1.5,             scale = 2)
+Dpareto3 <- dpareto3(Rpareto3, min = m,               shape  = 1.5,             scale = 2)
+Dpareto2 <- dpareto2(Rpareto2, min = m, shape  = 0.8,                           scale = 2)
+Dtrbeta        <- dtrbeta      (Rtrbeta,       shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
+Dburr          <- dburr        (Rburr,         shape1 = 0.8, shape2 = 1.5,             scale = 2)
+Dllogis        <- dllogis      (Rllogis,       shape  = 1.5, scale = 2)
+Dparalogis     <- dparalogis   (Rparalogis,    shape  = 0.8, scale = 2)
+Dgenpareto     <- dgenpareto   (Rgenpareto,    shape1 = 0.8, shape2 = 2, scale = 2)
+Dpareto        <- dpareto      (Rpareto,       shape  = 0.8, scale = 2)
+Dpareto1       <- dpareto1     (Rpareto1,      shape  = 0.8, min = 2)
+Dinvburr       <- dinvburr     (Rinvburr,      shape1 = 1.5, shape2 = 2, scale = 2)
+Dinvpareto     <- dinvpareto   (Rinvpareto,    shape  = 2,   scale = 2)
+Dinvparalogis  <- dinvparalogis(Rinvparalogis, shape  = 2,   scale = 2)
+Dtrgamma       <- dtrgamma     (Rtrgamma,      shape1 = 2, shape2 = 3, scale = 5)
+Dinvtrgamma    <- dinvtrgamma  (Rinvtrgamma,   shape1 = 2, shape2 = 3, scale = 5)
+Dinvgamma      <- dinvgamma    (Rinvtrgamma,   shape  = 2,             scale = 5)
+Dinvweibull    <- dinvweibull  (Rinvweibull,               shape  = 3, scale = 5)
+Dinvexp        <- dinvexp      (Rinvexp,                               scale = 5)
+Dlgamma <- dlgamma(Rlgamma, shapelog = 1.5, ratelog = 5)
+Dgumbel <- dgumbel(Rgumbel, alpha = 2, scale = 5)
+Dinvgauss <- dinvgauss(Rinvgauss, mean = 2, dispersion = 5)
+Dgenbeta <- dgenbeta(Rgenbeta, shape1 = 0.8, shape2 = 1.5, shape3 = 2, scale = 2)
 
 ## Check q<dist>(p<dist>(.)) identity
 stopifnot(exprs = {
@@ -1919,61 +1919,61 @@ n <- 20
 ## For zero-modified distributions, we simulate two sets of values:
 ## one with p0m < p0 (suffix 'p0lt') and one with p0m > p0 (suffix
 ## 'p0gt').
-(Rztpois      <- rztpois     (n, lambda = 12))
-(Rztnbinom    <- rztnbinom   (n, size = 7, prob = 0.01))
-(Rztgeom      <- rztgeom     (n, prob = pi/16))
-(Rztbinom     <- rztbinom    (n, size = 55, prob = pi/16))
-(Rlogarithmic <- rlogarithmic(n, prob = 0.99))
-(Rzmpoisp0lt        <- rzmpois       (n, lambda = 6, p0 = 0.001))
-(Rzmpoisp0gt        <- rzmpois       (n, lambda = 6, p0 = 0.010))
-(Rzmnbinomp0lt      <- rzmnbinom     (n, size = 7, prob = 0.8, p0 = 0.01))
-(Rzmnbinomp0gt      <- rzmnbinom     (n, size = 7, prob = 0.8, p0 = 0.40))
-(Rzmgeomp0lt        <- rzmgeom       (n, prob = pi/16, p0 = 0.01))
-(Rzmgeomp0gt        <- rzmgeom       (n, prob = pi/16, p0 = 0.40))
-(Rzmbinomp0lt       <- rzmbinom      (n, size = 12, prob = pi/16, p0 = 0.01))
-(Rzmbinomp0gt       <- rzmbinom      (n, size = 12, prob = pi/16, p0 = 0.12))
-(Rzmlogarithmicp0lt <- rzmlogarithmic(n, prob = 0.99, p0 = 0.05))
-(Rzmlogarithmicp0gt <- rzmlogarithmic(n, prob = 0.99, p0 = 0.55))
-(Rpoisinvgauss    <- rpoisinvgauss(n, mean = 12,  dispersion = 0.1))
-(RpoisinvgaussInf <- rpoisinvgauss(n, mean = Inf, dispersion = 1.1))
+Rztpois      <- rztpois     (n, lambda = 12)
+Rztnbinom    <- rztnbinom   (n, size = 7, prob = 0.01)
+Rztgeom      <- rztgeom     (n, prob = pi/16)
+Rztbinom     <- rztbinom    (n, size = 55, prob = pi/16)
+Rlogarithmic <- rlogarithmic(n, prob = 0.99)
+Rzmpoisp0lt        <- rzmpois       (n, lambda = 6, p0 = 0.001)
+Rzmpoisp0gt        <- rzmpois       (n, lambda = 6, p0 = 0.010)
+Rzmnbinomp0lt      <- rzmnbinom     (n, size = 7, prob = 0.8, p0 = 0.01)
+Rzmnbinomp0gt      <- rzmnbinom     (n, size = 7, prob = 0.8, p0 = 0.40)
+Rzmgeomp0lt        <- rzmgeom       (n, prob = pi/16, p0 = 0.01)
+Rzmgeomp0gt        <- rzmgeom       (n, prob = pi/16, p0 = 0.40)
+Rzmbinomp0lt       <- rzmbinom      (n, size = 12, prob = pi/16, p0 = 0.01)
+Rzmbinomp0gt       <- rzmbinom      (n, size = 12, prob = pi/16, p0 = 0.12)
+Rzmlogarithmicp0lt <- rzmlogarithmic(n, prob = 0.99, p0 = 0.05)
+Rzmlogarithmicp0gt <- rzmlogarithmic(n, prob = 0.99, p0 = 0.55)
+Rpoisinvgauss    <- rpoisinvgauss(n, mean = 12,  dispersion = 0.1)
+RpoisinvgaussInf <- rpoisinvgauss(n, mean = Inf, dispersion = 1.1)
 
 ## Compute quantiles
-(Pztpois      <- pztpois     (Rztpois,      lambda = 12))
-(Pztnbinom    <- pztnbinom   (Rztnbinom,    size = 7, prob = 0.01))
-(Pztgeom      <- pztgeom     (Rztgeom,      prob = pi/16))
-(Pztbinom     <- pztbinom    (Rztbinom,     size = 55, prob = pi/16))
-(Plogarithmic <- plogarithmic(Rlogarithmic, prob = 0.99))
-(Pzmpoisp0lt        <- pzmpois       (Rzmpoisp0lt,        lambda = 6, p0 = 0.001))
-(Pzmpoisp0gt        <- pzmpois       (Rzmpoisp0gt,        lambda = 6, p0 = 0.010))
-(Pzmnbinomp0lt      <- pzmnbinom     (Rzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01))
-(Pzmnbinomp0gt      <- pzmnbinom     (Rzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40))
-(Pzmgeomp0lt        <- pzmgeom       (Rzmgeomp0lt,        prob = pi/16, p0 = 0.01))
-(Pzmgeomp0gt        <- pzmgeom       (Rzmgeomp0gt,        prob = pi/16, p0 = 0.40))
-(Pzmbinomp0lt       <- pzmbinom      (Rzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01))
-(Pzmbinomp0gt       <- pzmbinom      (Rzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12))
-(Pzmlogarithmicp0lt <- pzmlogarithmic(Rzmlogarithmicp0lt, prob = 0.99, p0 = 0.05))
-(Pzmlogarithmicp0gt <- pzmlogarithmic(Rzmlogarithmicp0gt, prob = 0.99, p0 = 0.55))
-(Ppoisinvgauss    <- ppoisinvgauss(Rpoisinvgauss,    mean = 12,  dispersion = 0.1))
-(PpoisinvgaussInf <- ppoisinvgauss(RpoisinvgaussInf, mean = Inf, dispersion = 1.1))
+Pztpois      <- pztpois     (Rztpois,      lambda = 12)
+Pztnbinom    <- pztnbinom   (Rztnbinom,    size = 7, prob = 0.01)
+Pztgeom      <- pztgeom     (Rztgeom,      prob = pi/16)
+Pztbinom     <- pztbinom    (Rztbinom,     size = 55, prob = pi/16)
+Plogarithmic <- plogarithmic(Rlogarithmic, prob = 0.99)
+Pzmpoisp0lt        <- pzmpois       (Rzmpoisp0lt,        lambda = 6, p0 = 0.001)
+Pzmpoisp0gt        <- pzmpois       (Rzmpoisp0gt,        lambda = 6, p0 = 0.010)
+Pzmnbinomp0lt      <- pzmnbinom     (Rzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01)
+Pzmnbinomp0gt      <- pzmnbinom     (Rzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40)
+Pzmgeomp0lt        <- pzmgeom       (Rzmgeomp0lt,        prob = pi/16, p0 = 0.01)
+Pzmgeomp0gt        <- pzmgeom       (Rzmgeomp0gt,        prob = pi/16, p0 = 0.40)
+Pzmbinomp0lt       <- pzmbinom      (Rzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01)
+Pzmbinomp0gt       <- pzmbinom      (Rzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12)
+Pzmlogarithmicp0lt <- pzmlogarithmic(Rzmlogarithmicp0lt, prob = 0.99, p0 = 0.05)
+Pzmlogarithmicp0gt <- pzmlogarithmic(Rzmlogarithmicp0gt, prob = 0.99, p0 = 0.55)
+Ppoisinvgauss    <- ppoisinvgauss(Rpoisinvgauss,    mean = 12,  dispersion = 0.1)
+PpoisinvgaussInf <- ppoisinvgauss(RpoisinvgaussInf, mean = Inf, dispersion = 1.1)
 
 ## Just compute pmf
-dztpois     (Rztpois,      lambda = 12)
-dztnbinom   (Rztnbinom,    size = 7, prob = 0.01)
-dztgeom     (Rztgeom,      prob = pi/16)
-dztbinom    (Rztbinom,     size = 55, prob = pi/16)
-dlogarithmic(Rlogarithmic, prob = pi/16)
-dzmpois       (Rzmpoisp0lt,        lambda = 6, p0 = 0.001)
-dzmpois       (Rzmpoisp0gt,        lambda = 6, p0 = 0.010)
-dzmnbinom     (Rzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01)
-dzmnbinom     (Rzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40)
-dzmgeom       (Rzmgeomp0lt,        prob = pi/16, p0 = 0.01)
-dzmgeom       (Rzmgeomp0gt,        prob = pi/16, p0 = 0.40)
-dzmbinom      (Rzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01)
-dzmbinom      (Rzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12)
-dzmlogarithmic(Rzmlogarithmicp0lt, prob = 0.99, p0 = 0.05)
-dzmlogarithmic(Rzmlogarithmicp0gt, prob = 0.99, p0 = 0.55)
-dpoisinvgauss(Rpoisinvgauss,    mean = 12,  dispersion = 0.1)
-dpoisinvgauss(RpoisinvgaussInf, mean = Inf, dispersion = 1.1)
+Dztpois      <- dztpois     (Rztpois,      lambda = 12)
+Dztnbinom    <- dztnbinom   (Rztnbinom,    size = 7, prob = 0.01)
+Dztgeom      <- dztgeom     (Rztgeom,      prob = pi/16)
+Dztbinom     <- dztbinom    (Rztbinom,     size = 55, prob = pi/16)
+Dlogarithmic <- dlogarithmic(Rlogarithmic, prob = pi/16)
+Dzmpoisp0lt        <- dzmpois       (Rzmpoisp0lt,        lambda = 6, p0 = 0.001)
+Dzmpoisp0gt        <- dzmpois       (Rzmpoisp0gt,        lambda = 6, p0 = 0.010)
+Dzmnbinomp0lt      <- dzmnbinom     (Rzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01)
+Dzmnbinomp0gt      <- dzmnbinom     (Rzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40)
+Dzmgeomp0lt        <- dzmgeom       (Rzmgeomp0lt,        prob = pi/16, p0 = 0.01)
+Dzmgeomp0gt        <- dzmgeom       (Rzmgeomp0gt,        prob = pi/16, p0 = 0.40)
+Dzmbinomp0lt       <- dzmbinom      (Rzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01)
+Dzmbinomp0gt       <- dzmbinom      (Rzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12)
+Dzmlogarithmicp0lt <- dzmlogarithmic(Rzmlogarithmicp0lt, prob = 0.99, p0 = 0.05)
+Dzmlogarithmicp0gt <- dzmlogarithmic(Rzmlogarithmicp0gt, prob = 0.99, p0 = 0.55)
+Dpoisinvgauss    <- dpoisinvgauss(Rpoisinvgauss,    mean = 12,  dispersion = 0.1)
+DpoisinvgaussInf <- dpoisinvgauss(RpoisinvgaussInf, mean = Inf, dispersion = 1.1)
 
 ## Check q<dist>(p<dist>(.)) identity
 stopifnot(exprs = {
